![Version](https://img.shields.io/static/v1?label=version&color=informational&message=1.0.2)
![Build Status](https://drone-ext.mcos.nc/api/badges/scrippy/scrippy-installer/status.svg) ![License](https://img.shields.io/static/v1?label=license&color=orange&message=MIT) ![Language](https://img.shields.io/static/v1?label=language&color=informational&message=Python)

# Scrippy installer

This is the [**Scrippy**](https://codeberg.org/scrippy) framework installer helper.

## Configure and install [*the Scrippy scripting framework*](https://codeberg.org/scrippy/) with default value

  ```shell
  pip install scrippy
  scrippy install
  ```

## Configure and install [*the Scrippy scripting framework*](https://codeberg.org/scrippy/) interactively

  ```shell
  pip install scrippy
  scrippy install -i
  ```

## Configure and install [*the Scrippy scripting framework*](https://codeberg.org/scrippy/) from custom configuration file

  ```shell
  pip install scrippy
  scrippy install -c /path/to/config.yml
  ```
